@@ -1,10 +1,6 @@
 __license__ = "MIT"
 __project__ = "Marshmallow-Peewee"
-__version__ = "2.1.0"
-
-import marshmallow as ma
-
-MA_VERSION = ma.__version__.split('.')
+__version__ = "3.1.0"
 
 from .schema import ModelSchema # noqa
 from .fields import Timestamp, MSTimestamp, Related, ForeignKey # noqa
